self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/pages/index-8ef9d31305454b4d.js"],"/404":["static/chunks/pages/404-956c91c54dbf7529.js"],"/_error":["static/chunks/pages/_error-5e4bf06de1f960a6.js"],"/admin/group/[groupName]":["static/chunks/pages/admin/group/[groupName]-7637a93c49874015.js"],"/admin/groups":["static/chunks/pages/admin/groups-743e9d5dc61960fc.js"],"/admin/role/[roleName]":["static/chunks/pages/admin/role/[roleName]-da784f78d4a393ff.js"],"/admin/roles":["static/chunks/pages/admin/roles-bbe424811d5c6b72.js"],"/admin/user/[userName]":["static/chunks/pages/admin/user/[userName]-7e446d4e6072fd96.js"],"/admin/users":["static/chunks/pages/admin/users-5951b205cba48a21.js"],"/connections":["static/chunks/pages/connections-4a4b87472cb973a7.js"],"/query":["static/chunks/pages/query-cd56ee763a7d97b0.js"],"/search":["static/chunks/pages/search-870ecb6eb8a16eb1.js"],"/[type]":["static/chunks/pages/[type]-ddc986517d5618c1.js"],"/[type]/[entity]":["static/chunks/pages/[type]/[entity]-6fafd12f9142d665.js"],sortedPages:["/","/404","/_app","/_error","/admin/group/[groupName]","/admin/groups","/admin/role/[roleName]","/admin/roles","/admin/user/[userName]","/admin/users","/connections","/query","/search","/[type]","/[type]/[entity]"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();