"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7250],{62260:function(s){function t(s){s.languages.bbcode={tag:{pattern:/\[\/?[^\s=\]]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))?(?:\s+[^\s=\]]+\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))*\s*\]/,inside:{tag:{pattern:/^\[\/?[^\s=\]]+/,inside:{punctuation:/^\[\/?/}},"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+)/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\]/,"attr-name":/[^\s=\]]+/}}},s.languages.shortcode=s.languages.bbcode}s.exports=t,t.displayName="bbcode",t.aliases=["shortcode"]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_bbcode.a5ea9485b4c4deb1.js.map