"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[81],{56267:function(t){function e(t){t.languages.properties={comment:/^[ \t]*[#!].*$/m,"attr-value":{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?: *[=:] *(?! )| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0},"attr-name":/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?= *[=:]| )/m,punctuation:/[=:]/}}t.exports=e,e.displayName="properties",e.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_properties.4cfd32952e4b7d24.js.map